@@ -7,8 +7,8 @@ class HomePage(qrunner.Page):
     LOC_MY = {'id_': 'id/bottom_view', 'index': 3, 'desc': '首页底部我的入口'}
     
     def go_my(self):
-        self.elem(self.LOC_AD_CLOSE).click()
-        self.elem(self.LOC_MY).click()
+        self.elem(**self.LOC_AD_CLOSE).click()
+        self.elem(**self.LOC_MY).click()
 
 
 @story('首页')
