@@ -1,13 +1,13 @@
 import qrunner
-from qrunner import title, file_data, story
+from qrunner import file_data
 
 
-@story('PC站首页')
 class TestClass(qrunner.TestCase):
+    """pc首页"""
 
-    @title('查询PC站首页banner列表')
     @file_data('card_type', 'data.json')
     def test_getToolCardListForPc(self, card_type):
+        """首页金刚位"""
         path = '/api/qzd-bff-app/qzd/v1/home/getToolCardListForPc'
         payload = {"type": card_type}
         self.post(path, json=payload)
@@ -17,5 +17,5 @@ class TestClass(qrunner.TestCase):
 if __name__ == '__main__':
     qrunner.main(
         platform='api',
-        base_url='https://www-pre.qizhidao.com'
+        base_url='https://www.qizhidao.com'
     )
