@@ -4,12 +4,12 @@ from qrunner import story, title
 
 class PatentPage(qrunner.Page):
     url = None
-    LOC_SEARCH_INPUT = {'id_': 'driver-home-step1', 'desc': '查专利首页输入框'}
-    LOC_SEARCH_SUBMIT = {'id_': 'driver-home-step2', 'desc': '查专利首页搜索确认按钮'}
+    search_input = {'id_': 'driver-home-step1', 'desc': '查专利首页输入框'}
+    search_submit = {'id_': 'driver-home-step2', 'desc': '查专利首页搜索确认按钮'}
     
     def simple_search(self):
-        self.elem(**self.LOC_SEARCH_INPUT).set_text('无人机')
-        self.elem(**self.LOC_SEARCH_SUBMIT).click()
+        self.elem(**self.search_input).set_text('无人机')
+        self.elem(**self.search_submit).click()
 
 
 @story('专利检索')
