@@ -16,6 +16,7 @@ from qrunner.case import TestCase
 from qrunner.page import Page
 from qrunner.utils.mail import Mail
 from qrunner.utils.dingtalk import DingTalk
+from qrunner.utils.json_utils import get_schema
 
-__version__ = "1.0.7"
-__description__ = "全平台自动化测试框架"
+__version__ = "1.0.18"
+__description__ = "Api/Web/App端自动化测试框架"
