@@ -1,20 +1,17 @@
 import re
 import time
 from typing import Union
-
 import jmespath
-
 from qrunner.core.api.request import ResponseResult, HttpRequest
-from qrunner.utils.decorate import step
 from qrunner.core.web.driver import WebDriver
-from qrunner.core.web.element import WebElement
 from qrunner.core.h5.driver import H5Driver
 from qrunner.core.ios.driver import IosDriver
-from qrunner.core.ios.element import IosElement
 from qrunner.utils.log import logger
 from qrunner.utils.config import config
 from qrunner.core.android.driver import AndroidDriver
-from qrunner.core.android.element import AndroidElement
+from jsonschema import validate
+from jsonschema.exceptions import ValidationError
+from qrunner.core.api.request import formatting
 
 
 class TestCase(HttpRequest):
@@ -42,7 +39,7 @@ class TestCase(HttpRequest):
     def setup_class(cls):
         # 初始化driver
         platform = config.get_platform()
-        logger.info(platform)
+        # logger.info(platform)
         if platform == 'android':
             serial_no = config.get_device()
             cls.driver = AndroidDriver(serial_no)
@@ -76,7 +73,6 @@ class TestCase(HttpRequest):
 
     def setup_method(self):
         self.start_time = time.time()
-        logger.debug(f"[start_time]: {time.strftime('%Y-%m-%d %H:%M:%S')}")
         # 启动应用
         # self.driver.force_start_app()
         self.start()
@@ -87,7 +83,6 @@ class TestCase(HttpRequest):
         # self.screenshot('用例执行完成截图')
         # 退出应用
         # self.driver.stop_app()
-        logger.debug(f"[end_time]: {time.strftime('%Y-%m-%d %H:%M:%S')}")
         take_time = time.time() - self.start_time
         logger.debug("[run_time]: {:.2f} s".format(take_time))
 
@@ -103,14 +98,15 @@ class TestCase(HttpRequest):
         self.driver.screenshot(file_name)
 
     def elem(self, **kwargs):
-        if isinstance(self.driver, AndroidDriver):
-            return AndroidElement(self.driver, **kwargs)
-        elif isinstance(self.driver, WebDriver):
-            return WebElement(self.driver, **kwargs)
-        elif isinstance(self.driver, IosDriver):
-            return IosElement(self.driver, **kwargs)
-        else:
-            return None
+        # if isinstance(self.driver, AndroidDriver):
+        #     return AndroidElement(self.driver, **kwargs)
+        # elif isinstance(self.driver, WebDriver):
+        #     return WebElement(self.driver, **kwargs)
+        # elif isinstance(self.driver, IosDriver):
+        #     return IosElement(self.driver, **kwargs)
+        # else:
+        #     return None
+        return self.driver.get_elem(**kwargs)
 
     def assertText(self, expect_value, timeout=5):
         """断言页面包含文本"""
@@ -292,6 +288,22 @@ class TestCase(HttpRequest):
         assert actual_code == status_code, \
             f'status_code {ResponseResult} != {status_code}'
 
+    @staticmethod
+    def assertSchema(schema, response=None) -> None:
+        """
+        Assert JSON Schema
+        doc: https://json-schema.org/
+        """
+        logger.info(f"assertSchema -> {formatting(schema)}.")
+
+        if response is None:
+            response = ResponseResult.response
+
+        try:
+            validate(instance=response, schema=schema)
+        except ValidationError as msg:
+            assert "Response data" == "Schema data", msg
+
     @staticmethod
     def assertPath(path, value):
         """
@@ -302,6 +314,16 @@ class TestCase(HttpRequest):
         logger.info(f'断言: {search_value} 等于 {value}')
         assert search_value == value, f'{search_value} != {value}'
 
+    @staticmethod
+    def assertEq(path, value):
+        """
+        功能同assertPath，用于兼容历史代码
+        doc: https://jmespath.org/
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        logger.info(f'断言: {search_value} 等于 {value}')
+        assert search_value == value, f'{search_value} != {value}'
+
     @staticmethod
     def assertNotEq(path, value):
         """
