@@ -6,6 +6,7 @@ from qrunner.utils.config import config
 from qrunner.utils.log import logger
 from qrunner.utils.exceptions import DeviceNotFoundException, ScreenFailException
 from qrunner.core.android.common import get_device_list
+from qrunner.core.android.element import AndroidElement
 
 
 class AndroidDriver(object):
@@ -35,6 +36,10 @@ class AndroidDriver(object):
             return AndroidDriver(serial_no)
         return AndroidDriver._instance[serial_no]
 
+    @staticmethod
+    def get_elem(**kwargs):
+        return AndroidElement(**kwargs)
+
     def uninstall_app(self, pkg_name=None):
         """卸载应用"""
         if not pkg_name:
