@@ -3,34 +3,39 @@
 # @File    : request.py
 import sys
 from urllib import parse
-import allure
 import requests
 import json as json_util
-from qrunner.utils.config import conf
-from qrunner.utils.log import logger
+from deepdiff import DeepDiff
 
-IMG = ["jpg", "jpeg", "gif", "bmp", "webp"]
+from qrunner.utils.json_utils import get_schema, formatting
+from qrunner.utils.config import config
+from qrunner.utils.log import logger
+import logging
+
+# 去掉requests本身的日志
+urllib3_logger = logging.getLogger('urllib3')
+urllib3_logger.setLevel(logging.CRITICAL)
+
+# IMG = ["jpg", "jpeg", "gif", "bmp", "webp"]
 
 
 def request(func):
     def wrapper(*args, **kwargs):
-        func_name = func.__name__
-        print("\n")
         logger.info('-------------- Request -----------------[🚀]')
+        # 给接口带上默认域名
         try:
             path = list(args)[1]
         except IndexError:
             path = kwargs.get("url", "")
 
-        args_new = args
         if "http" not in path:
-            base_url = conf.get_item('common', 'base_url')
+            base_url = config.get_host()
             if 'http' in base_url:
                 url = parse.urljoin(base_url, path)
                 try:
                     args_list = list(args)
                     args_list[1] = url
-                    args_new = tuple(args_list)
+                    args = tuple(args_list)
                 except Exception:
                     kwargs['url'] = url
             else:
@@ -39,73 +44,69 @@ def request(func):
         else:
             url = path
 
-        img_file = False
-        file_type = url.split(".")[-1]
-        if file_type in IMG:
-            img_file = True
+        # img_file = False
+        # file_type = url.split(".")[-1]
+        # if file_type in IMG:
+        #     img_file = True
 
-        logger.debug("[method]: {m}      [url]: {u} \n".format(m=func_name.upper(), u=url))
-        auth = kwargs.get("auth", "")
-
-        # 根据login标记获取登录用户或游客的请求头
+        # 请求头处理，写入登录态
         login_status = kwargs.get('login', True)
-        if login_status:
-            tmp_headers: dict = conf.get_item('common', 'login_headers')
-        else:
-            tmp_headers: dict = conf.get_item('common', 'visit_headers')
-        # 把上层请求方法的headers参数更新到headers里面
+        tmp_headers = config.get_login() if login_status is True else config.get_visit()
         if tmp_headers:
             tmp_headers.update(kwargs.pop('headers', {}))
             kwargs['headers'] = tmp_headers
 
-        # 设置请求超时时间为10s
-        timeout = conf.get_item('common', 'timeout')
-        timeout_set = kwargs.pop("timeout", None)
-        if timeout_set is not None:
-            kwargs['timeout'] = timeout_set
-        else:
-            kwargs['timeout'] = int(timeout)
+        # 设置默认超时时间
+        timeout_config = config.get_timeout()
+        timeout_user_set = kwargs.pop("timeout", None)
+        kwargs['timeout'] = timeout_user_set if timeout_user_set is not None else timeout_config
 
+        # 获取日志需要的参数信息
+        auth = kwargs.get("auth", "")
         cookies = kwargs.get("cookies", "")
         params = kwargs.get("params", "")
         data = kwargs.get("data", "")
         json = kwargs.get("json", "")
-        desc = kwargs.pop("desc", None)
 
-        # running function
-        if desc is None:
-            desc = f'请求 {path} 接口'
-        with allure.step(desc):
-            r = func(*args_new, **kwargs)
+        # 发送请求
+        r = func(*args, **kwargs)
 
+        # 输出请求参数日志
+        logger.debug("[method]: {m}      [url]: {u}".format(m=func.__name__.upper(), u=url))
         if auth != "":
-            logger.debug(f"[auth]:\n {json_util.dumps(auth, ensure_ascii=False)} \n")
-        logger.debug(f"[headers]:\n {json_util.dumps(dict(r.request.headers), ensure_ascii=False)} \n")
+            logger.debug(f"[auth]:\n {formatting(auth)}")
+        logger.debug(f"[headers]:\n {formatting(dict(r.request.headers))}")
         if cookies != "":
-            logger.debug(f"[cookies]:\n {json_util.dumps(cookies, ensure_ascii=False)} \n")
+            logger.debug(f"[cookies]:\n {formatting(cookies)}")
         if params != "":
-            logger.debug(f"[params]:\n {json_util.dumps(params, ensure_ascii=False)} \n")
+            logger.debug(f"[params]:\n {formatting(params)}")
         if data != "":
-            logger.debug(f"[data]:\n {json_util.dumps(data, ensure_ascii=False)} \n")
+            logger.debug(f"[data]:\n {formatting(data)}")
         if json != "":
-            logger.debug(f"[json]:\n {json_util.dumps(json, ensure_ascii=False)} \n")
+            logger.debug(f"[json]:\n {formatting(json)}")
 
-        ResponseResult.status_code = r.status_code
+        # 保存响应结果并输出日志
+        status_code = r.status_code
+        headers = r.headers
+        content_type = headers.get('Content-Type')
+        ResponseResult.status_code = status_code
         logger.info("-------------- Response ----------------")
+        logger.debug(f"[status]: {status_code}")
+        logger.debug(f"[headers]: {formatting(headers)}")
         try:
             resp = r.json()
-            logger.debug(f"[type]: json \n")
-            logger.debug(f"[response]:\n {json_util.dumps(resp, ensure_ascii=False)} \n")
+            logger.debug(f"[type]: json")
+            logger.debug(f"[response]:\n {formatting(resp)}")
             ResponseResult.response = resp
-        except BaseException as msg:
-            # 非json响应数据，最多打印100个字符
-            logger.debug("[warning]: {} \n".format(str(msg)[:100]))
-            if img_file is True:
-                logger.debug("[type]: {}".format(file_type))
+        except Exception:
+            # 非json响应数据，根据响应内容类型进行判断
+            if 'text' not in content_type:
+                logger.debug(f"[type]: {content_type}")
+                logger.debug(f"[response]:\n {r.content}")
                 ResponseResult.response = r.content
             else:
-                logger.debug("[type]: text \n")
-                logger.debug(f"[response]:\n {r.text} \n")
+                logger.debug(f"[type]: {content_type}")
+                logger.debug(f"[response]:\n {r.text}")
                 ResponseResult.response = r.text
 
     return wrapper
@@ -129,6 +130,27 @@ class HttpRequest(object):
         #         sys.exit()
         return requests.get(url, params=params, **kwargs)
 
+    def get_req_schema(self, *args, **kwargs):
+        """get请求，检查多次请求返回的schema是否稳定"""
+        exclude_paths = kwargs.pop('exclude_paths', {})
+        execute_time = kwargs.pop('execute_time', 10)
+
+        self.get(*args, **kwargs)
+        schema_start = get_schema(self.response)
+        diff_result = []
+
+        for i in range(execute_time):
+            logger.debug(f'第 {i+1} 次执行')
+            self.get(*args, **kwargs)
+            schema_ = get_schema(self.response)
+            result = DeepDiff(schema_start, schema_, exclude_paths=exclude_paths)
+            diff_result.append(result)
+
+        logger.debug(f'diff结果:')
+        for item in diff_result:
+            for item_ in item.items():
+                print(item_)
+
     @request
     def post(self, url, data=None, json=None, login=True, **kwargs):
         # if "http" not in url:
@@ -141,6 +163,28 @@ class HttpRequest(object):
         #         sys.exit()
         return requests.post(url, data=data, json=json, **kwargs)
 
+    def post_req_schema(self, *args, **kwargs):
+        """post请求，检查多次请求返回的schema是否稳定"""
+        exclude_paths = kwargs.pop('exclude_paths', {})
+        execute_time = kwargs.pop('execute_time', 10)
+
+        self.post(*args, **kwargs)
+        schema_start = get_schema(self.response)
+        diff_result = []
+
+        for i in range(execute_time):
+            logger.debug(f'第 {i+1} 次执行')
+            self.post(*args, **kwargs)
+            schema_ = get_schema(self.response)
+            result = DeepDiff(schema_start, schema_, exclude_paths=exclude_paths)
+            diff_result.append(result)
+
+        logger.debug(f'diff结果:')
+        for item in diff_result:
+            for item_ in item.items():
+                print(item_)
+
+
     @request
     def put(self, url, data=None, json=None, login=True, **kwargs):
         # if "http" not in url:
