@@ -7,12 +7,14 @@ import allure
 import requests
 # from baseImage import Image, Rect
 from selenium import webdriver
+from selenium.webdriver import ChromeOptions
 
 # from qrunner.core.image.element import ImageRecognition
-from qrunner.utils.config import conf
+from qrunner.utils.config import config
 from qrunner.utils.log import logger
 from qrunner.utils.webdriver_manager_extend import ChromeDriverManager
 from qrunner.core.android.driver import AndroidDriver
+from qrunner.core.web.element import WebElement
 
 
 # class H5Config:
@@ -31,6 +33,12 @@ from qrunner.core.android.driver import AndroidDriver
 from qrunner.utils.exceptions import ScreenFailException
 
 
+class ChromeConfig:
+    headless = False
+    options = None
+    command_executor = ""
+
+
 def get_server_chrome_versions():
     """获取淘宝镜像网站上所有的版本列表"""
     version_list = []
@@ -109,43 +117,26 @@ class H5Driver(object):
         options.add_experimental_option('androidPackage', pkg_name)
         options.add_experimental_option('androidUseRunningApp', True)
         options.add_experimental_option('androidProcess', pkg_name)
-        try:
-            exe_path = conf.get_item('common', 'executable_path')
-            logger.debug(f'在指定目录查找驱动: {exe_path}')
-            self.d = webdriver.Chrome(
-                executable_path=exe_path,
-                options=options
-            )
-            logger.debug('h5Driver初始化成功')
-        except Exception as e:
-            logger.debug('在指定目录查找驱动失败!')
-            logger.debug(e)
-            for i in range(3):
-                logger.debug(f'第 {i+1} 次在淘宝镜像查找驱动:')
-                try:
-                    version = get_driver_version(serial_no, pkg_name)
-                    exe_path = ChromeDriverManager(version=version).install()
-                    self.d = webdriver.Chrome(
-                        executable_path=exe_path,
-                        options=options
-                    )
-                    logger.debug('h5Driver初始化成功')
-                    break
-                except Exception as e:
-                    logger.debug(f'第 {i+1} 次查找失败: {str(e)}')
-                    logger.debug(f'第 {i + 1} 次重试')
-                    time.sleep(3)
-            else:
-                logger.debug('重试3次失败，h5Driver初始化失败')
-                sys.exit()
+        for i in range(3):
+            logger.debug(f'第 {i + 1} 次在淘宝镜像查找驱动:')
+            try:
+                version = get_driver_version(serial_no, pkg_name)
+                self.d = webdriver.Chrome(
+                    executable_path=ChromeDriverManager(version=version).install(),
+                    options=options
+                )
+                logger.debug('h5Driver初始化成功')
+                break
+            except Exception as e:
+                logger.debug(f'第 {i + 1} 次查找失败: {str(e)}')
+                logger.debug(f'第 {i + 1} 次重试')
+                time.sleep(3)
+        else:
+            logger.debug('重试3次失败，h5Driver初始化失败')
+            sys.exit()
 
         # 设置页面加载超时时间
-        try:
-            timeout = int(conf.get_item('common', 'timeout'))
-        except:
-            pass
-        else:
-            self.d.set_page_load_timeout(timeout)
+        self.d.set_page_load_timeout(config.get_timeout())
 
     # @staticmethod
     # def get_instance(cls, serial_no=None):
@@ -154,6 +145,10 @@ class H5Driver(object):
     #         return H5Driver(serial_no)
     #     return H5Driver._instance[serial_no]
 
+    @staticmethod
+    def get_elem(**kwargs):
+        return WebElement(**kwargs)
+
     def open_url(self, url):
         logger.info(f'访问: {url}')
         self.d.get(url)
@@ -219,8 +214,7 @@ class H5Driver(object):
     #                        name=f'{filename}-{get_time()}')
     #     os.remove('tmp.png')
 
-    @property
-    def page_content(self):
+    def get_page_content(self):
         page_source = self.d.page_source
         logger.info(f'获取页面内容: \n{page_source}')
         return page_source
