@@ -10,6 +10,7 @@ from qrunner.core.ios.common import get_device_list, get_tcp_port
 from qrunner.utils.log import logger
 from qrunner.utils.config import config
 from qrunner.utils.exceptions import DeviceNotFoundException, ScreenFailException
+from qrunner.core.ios.element import IosElement
 
 
 def _start_wda_xctest(udid: str, port, wda_bundle_id=None) -> bool:
@@ -61,6 +62,10 @@ class IosDriver(object):
             return IosDriver(serial_no)
         return IosDriver._instance[serial_no]
 
+    @staticmethod
+    def get_elem(**kwargs):
+        return IosElement(**kwargs)
+
     def install_app(self, ipa_url):
         """安装应用"""
         cmd = f'tidevice -u {self.serial_no} install {ipa_url}'
