@@ -3,7 +3,6 @@ from typing import Union
 from wda import Selector
 from qrunner.utils.log import logger
 from qrunner.utils.config import config
-from qrunner.core.ios.driver import IosDriver
 from qrunner.utils.exceptions import NoSuchElementException, \
     ElementNameEmptyException
 
@@ -50,7 +49,7 @@ class IosElement(object):
         if self.desc is None:
             raise ElementNameEmptyException('请设置控件名称')
         self._kwargs = kwargs
-        self._driver = None
+        self._driver = driver
 
         # # 驱动初始化
         # _serial_no = config.get_item('ios', 'serial_no')
@@ -58,12 +57,13 @@ class IosElement(object):
         # self._d = self._driver.d
 
     def get_driver(self):
-        if self._driver is not None :
-            driver = self._driver
-        else:
-            serial_no = config.get_device()
-            driver = IosDriver.get_instance(serial_no)
-        return driver
+        # if self._driver is not None :
+        #     driver = self._driver
+        # else:
+        #     serial_no = config.get_device()
+        #     driver = IosDriver.get_instance(serial_no)
+        # return driver
+        return self._driver
 
     # def _find_element(self, retry=3, timeout=3):
     #     """
